@@ -33,7 +33,7 @@ function rilDownloadList() {
     var xhr = new XMLHttpRequest;
     var params = rilGetParams();
     //console.log(params);
-    var url="https://readitlaterlist.com/v2/get";
+    var url="http://readitlaterlist.com/v2/get";
     var since=Storage.getSetting("rilLastUpdate");
     params = params + "&state=unread"
     if (since!="Unknown") {
@@ -89,7 +89,7 @@ function rilDownloadRilArticle(articleUrl) {
     var xhr = new XMLHttpRequest;
 
     var params = "apikey=" + Storage.getSetting("apikey")+"&images=1&url="+articleUrl;
-    var url="https://text.readitlaterlist.com/v2/text";
+    var url="http://text.readitlaterlist.com/v2/text";
     xhr.open("POST", url);
     xhr.setRequestHeader("Content-type", "application/x-www-form-urlencoded");
     xhr.setRequestHeader("Content-length", params.length);
@@ -173,7 +173,7 @@ function rilGet(listmodel) {
 function rilMarkAsRead(item) {
     // Mark an item as read. Parameter should be the URL of the item
     var params = rilGetParams();
-    var url = "https://readitlaterlist.com/v2/send";
+    var url = "http://readitlaterlist.com/v2/send";
     
     var req = {"0" : { "url" : item } };
     var jreq = JSON.stringify(req);
@@ -191,7 +191,7 @@ function updateList() {
 
 function checkLogin() {
     var params = rilGetParams();
-    var url = "https://readitlaterlist.com/v2/auth"
+    var url = "http://readitlaterlist.com/v2/auth"
     //console.log(params)
 
     var status = sendReq(url,params);
